You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by na...@apache.org on 2006/10/02 07:07:20 UTC

svn commit: r451883 - in /webservices/axis2/trunk/c: include/axis2_soap_over_http_sender.h modules/core/description/svc.c modules/core/transport/http/sender/http_transport_sender.c modules/core/transport/http/sender/soap_over_http_sender.c

Author: nandika
Date: Sun Oct  1 22:07:19 2006
New Revision: 451883

URL: http://svn.apache.org/viewvc?view=rev&rev=451883
Log:
incorrect prefix axiom renamed to axis2 , bug fixed in AXIS2_SVC_ADD_MAPPING

Modified:
    webservices/axis2/trunk/c/include/axis2_soap_over_http_sender.h
    webservices/axis2/trunk/c/modules/core/description/svc.c
    webservices/axis2/trunk/c/modules/core/transport/http/sender/http_transport_sender.c
    webservices/axis2/trunk/c/modules/core/transport/http/sender/soap_over_http_sender.c

Modified: webservices/axis2/trunk/c/include/axis2_soap_over_http_sender.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/include/axis2_soap_over_http_sender.h?view=diff&rev=451883&r1=451882&r2=451883
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/svc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/svc.c Sun Oct  1 22:07:19 2006
@@ -1981,7 +1981,7 @@
     AXIS2_PARAM_CHECK(env->error, op_desc, AXIS2_FAILURE);
     svc_impl = AXIS2_INTF_TO_IMPL(svc);
 
-    axis2_hash_set(svc_impl->op_action_map, mapping_key,
+    axis2_hash_set(svc_impl->op_action_map, AXIS2_STRDUP(mapping_key, env),
             AXIS2_HASH_KEY_STRING, op_desc);
     return AXIS2_SUCCESS;
 }

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/http_transport_sender.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/http_transport_sender.c?view=diff&rev=451883&r1=451882&r2=451883
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/http_transport_sender.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/http_transport_sender.c Sun Oct  1 22:07:19 2006
@@ -571,7 +571,7 @@
 {
     const axis2_char_t *soap_action = NULL;
     const axis2_char_t *url = NULL;
-    axiom_soap_over_http_sender_t *sender = NULL;
+    axis2_soap_over_http_sender_t *sender = NULL;
     axis2_status_t status = AXIS2_FAILURE;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
@@ -626,23 +626,23 @@
     }
     else
     {
-        sender = axiom_soap_over_http_sender_create(env);
+        sender = axis2_soap_over_http_sender_create(env);
 
         if (NULL == sender)
         {
             return AXIS2_FAILURE;
         }
-        AXIOM_SOAP_OVER_HTTP_SENDER_SET_CHUNKED(sender, env,
+        AXIS2_SOAP_OVER_HTTP_SENDER_SET_CHUNKED(sender, env,
                 AXIS2_INTF_TO_IMPL(transport_sender)->chunked);
-        AXIOM_SOAP_OVER_HTTP_SENDER_SET_OM_OUTPUT(sender, env, om_output);
+        AXIS2_SOAP_OVER_HTTP_SENDER_SET_OM_OUTPUT(sender, env, om_output);
         AXIOM_SOAP_OVER_SENDER_SET_HTTP_VERSION(sender, env,
                 AXIS2_INTF_TO_IMPL(transport_sender)->http_version);
-        status = AXIOM_SOAP_OVER_HTTP_SENDER_SEND(sender, env, msg_ctx, out, url
+        status = AXIS2_SOAP_OVER_HTTP_SENDER_SEND(sender, env, msg_ctx, out, url
                 , soap_action);
         /*
          * TODO check for errors
          */
-        AXIOM_SOAP_OVER_HTTP_SENDER_FREE(sender, env);
+        AXIS2_SOAP_OVER_HTTP_SENDER_FREE(sender, env);
         sender = NULL;
     }
     return status;

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/soap_over_http_sender.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/soap_over_http_sender.c?view=diff&rev=451883&r1=451882&r2=451883
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/soap_over_http_sender.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/soap_over_http_sender.c Sun Oct  1 22:07:19 2006
@@ -33,9 +33,9 @@
  *   Axis2 SOAP over HTTP sender impl
  */
 
-typedef struct axiom_soap_over_http_sender_impl
+typedef struct axis2_soap_over_http_sender_impl
 {
-    axiom_soap_over_http_sender_t sender;
+    axis2_soap_over_http_sender_t sender;
     axis2_char_t *http_version;
     axis2_bool_t chunked;
     int so_timeout;
@@ -43,35 +43,35 @@
     axiom_output_t *om_output;
     axis2_http_client_t *client;
 }
-axiom_soap_over_http_sender_impl_t;
+axis2_soap_over_http_sender_impl_t;
 
 #define AXIS2_INTF_TO_IMPL(sender) \
-                       ((axiom_soap_over_http_sender_impl_t *)(sender))
+                       ((axis2_soap_over_http_sender_impl_t *)(sender))
 
 /***************************** Function headers *******************************/
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_get_header_info(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_get_header_info(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axis2_http_simple_response_t *response);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_process_response(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_process_response(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axis2_http_simple_response_t *response);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_get_timeout_values(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_get_timeout_values(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_send(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_send(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axiom_soap_envelope_t *out,
@@ -79,46 +79,46 @@
     const axis2_char_t *soap_action);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_chunked(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_chunked(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_bool_t chunked);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_om_output(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_om_output(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axiom_output_t *om_output);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_http_version(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_http_version(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_char_t *version);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_configure_proxy(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_configure_proxy(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx);
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_free(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_free(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env);
 
 /***************************** End of function headers ************************/
 
-axiom_soap_over_http_sender_t *AXIS2_CALL
-axiom_soap_over_http_sender_create(
+axis2_soap_over_http_sender_t *AXIS2_CALL
+axis2_soap_over_http_sender_create(
     const axis2_env_t *env)
 {
-    axiom_soap_over_http_sender_impl_t *sender_impl = NULL;
+    axis2_soap_over_http_sender_impl_t *sender_impl = NULL;
     AXIS2_ENV_CHECK(env, NULL);
 
-    sender_impl = (axiom_soap_over_http_sender_impl_t *)AXIS2_MALLOC
+    sender_impl = (axis2_soap_over_http_sender_impl_t *)AXIS2_MALLOC
             (env->allocator, sizeof(
-                        axiom_soap_over_http_sender_impl_t));
+                        axis2_soap_over_http_sender_impl_t));
 
     if (NULL == sender_impl)
     {
@@ -137,34 +137,34 @@
     sender_impl->client = NULL;
 
     sender_impl->sender.ops = AXIS2_MALLOC(env->allocator,
-            sizeof(axiom_soap_over_http_sender_ops_t));
+            sizeof(axis2_soap_over_http_sender_ops_t));
     if (NULL == sender_impl->sender.ops)
     {
-        axiom_soap_over_http_sender_free((axiom_soap_over_http_sender_t *)
+        axis2_soap_over_http_sender_free((axis2_soap_over_http_sender_t *)
                 sender_impl, env);
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
 
     sender_impl->sender.ops->send =
-        axiom_soap_over_http_sender_send;
+        axis2_soap_over_http_sender_send;
     sender_impl->sender.ops->set_chunked =
-        axiom_soap_over_http_sender_set_chunked;
+        axis2_soap_over_http_sender_set_chunked;
     sender_impl->sender.ops->set_om_output =
-        axiom_soap_over_http_sender_set_om_output;
+        axis2_soap_over_http_sender_set_om_output;
     sender_impl->sender.ops->set_http_version =
-        axiom_soap_over_http_sender_set_http_version;
+        axis2_soap_over_http_sender_set_http_version;
     sender_impl->sender.ops->free =
-        axiom_soap_over_http_sender_free;
+        axis2_soap_over_http_sender_free;
     return &(sender_impl->sender);
 }
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_free(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_free(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env)
 {
-    axiom_soap_over_http_sender_impl_t *sender_impl = NULL;
+    axis2_soap_over_http_sender_impl_t *sender_impl = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
 
     sender_impl = AXIS2_INTF_TO_IMPL(sender);
@@ -186,8 +186,8 @@
 
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_send(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_send(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axiom_soap_envelope_t *out,
@@ -197,7 +197,7 @@
     axis2_http_simple_request_t *request = NULL;
     axis2_http_request_line_t *request_line = NULL;
     axis2_url_t *url = NULL;
-    axiom_soap_over_http_sender_impl_t *sender_impl = NULL;
+    axis2_soap_over_http_sender_impl_t *sender_impl = NULL;
     axiom_xml_writer_t *xml_writer = NULL;
     axis2_char_t *buffer = NULL;
     const axis2_char_t *char_set_enc = NULL;
@@ -236,7 +236,7 @@
     }
     /* configure proxy settings if we have set so
      */
-    axiom_soap_over_http_sender_configure_proxy(sender, env, msg_ctx);
+    axis2_soap_over_http_sender_configure_proxy(sender, env, msg_ctx);
     /* We put the client into msg_ctx so that we can free it once the processing
      * is done at client side
      */
@@ -407,7 +407,7 @@
         AXIS2_HTTP_SIMPLE_REQUEST_SET_BODY_STRING(request, env, buffer);
     }
 
-    axiom_soap_over_http_sender_get_timeout_values(sender, env, msg_ctx);
+    axis2_soap_over_http_sender_get_timeout_values(sender, env, msg_ctx);
     AXIS2_HTTP_CLIENT_SET_TIMEOUT(sender_impl->client, env,
             sender_impl->so_timeout);
 
@@ -429,7 +429,7 @@
     if (AXIS2_HTTP_RESPONSE_OK_CODE_VAL == status_code ||
             AXIS2_HTTP_RESPONSE_ACK_CODE_VAL == status_code)
     {
-        return axiom_soap_over_http_sender_process_response(sender, env,
+        return axis2_soap_over_http_sender_process_response(sender, env,
                 msg_ctx, response);
     }
     else if (AXIS2_HTTP_RESPONSE_INTERNAL_SERVER_ERROR_CODE_VAL == status_code)
@@ -466,7 +466,7 @@
                 AXIS2_HTTP_HEADER_ACCEPT_APPL_SOAP) || AXIS2_STRSTR(
                     tmp_header_val, AXIS2_HTTP_HEADER_ACCEPT_TEXT_XML)))
         {
-            return axiom_soap_over_http_sender_process_response(sender, env,
+            return axis2_soap_over_http_sender_process_response(sender, env,
                     msg_ctx, response);
         }
     }
@@ -477,8 +477,8 @@
 
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_chunked(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_chunked(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_bool_t chunked)
 {
@@ -489,8 +489,8 @@
 
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_om_output(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_om_output(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axiom_output_t *om_output)
 {
@@ -501,15 +501,15 @@
 
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_get_header_info(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_get_header_info(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axis2_http_simple_response_t *response)
 {
     axis2_array_list_t *headers = NULL;
     axis2_char_t *charset = NULL;
-    axiom_soap_over_http_sender_impl_t *sender_impl = NULL;
+    axis2_soap_over_http_sender_impl_t *sender_impl = NULL;
     int i = 0;
     axis2_bool_t response_chunked = AXIS2_FALSE;
     int *content_length = NULL;
@@ -620,8 +620,8 @@
 }
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_process_response(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_process_response(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     axis2_http_simple_response_t *response)
@@ -641,7 +641,7 @@
         return AXIS2_FAILURE;
     }
 
-    axiom_soap_over_http_sender_get_header_info(sender, env, msg_ctx, response);
+    axis2_soap_over_http_sender_get_header_info(sender, env, msg_ctx, response);
     /*axis_ctx = AXIS2_OP_CTX_GET_BASE(AXIS2_MSG_CTX_GET_OP_CTX(msg_ctx, env),
                   env);*/
     property = axis2_property_create(env);
@@ -656,8 +656,8 @@
 }
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_get_timeout_values(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_get_timeout_values(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx)
 {
@@ -694,8 +694,8 @@
 }
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_set_http_version(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_set_http_version(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_char_t *version)
 {
@@ -709,8 +709,8 @@
 }
 
 axis2_status_t AXIS2_CALL
-axiom_soap_over_http_sender_configure_proxy(
-    axiom_soap_over_http_sender_t *sender,
+axis2_soap_over_http_sender_configure_proxy(
+    axis2_soap_over_http_sender_t *sender,
     const axis2_env_t *env,
     axis2_msg_ctx_t *msg_ctx)
 {
@@ -720,7 +720,7 @@
     axis2_param_t *proxy_param = NULL;
     axis2_qname_t *transport_qname = NULL;
     axis2_hash_t *transport_attrs = NULL;
-    axiom_soap_over_http_sender_impl_t *sender_impl = NULL;
+    axis2_soap_over_http_sender_impl_t *sender_impl = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, msg_ctx, AXIS2_FAILURE);



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/include/axis2_soap_over_http_sender.h (original)
+++ webservices/axis2/trunk/c/include/axis2_soap_over_http_sender.h Sun Oct  1 22:07:19 2006
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIOM_SOAP_OVER_HTTP_SENDER_H
-#define AXIOM_SOAP_OVER_HTTP_SENDER_H
+#ifndef AXIS2_SOAP_OVER_HTTP_SENDER_H
+#define AXIS2_SOAP_OVER_HTTP_SENDER_H
 
 /**
  * @ingroup axis2_core_transport_http
@@ -23,7 +23,7 @@
  */
 
 /**
- * @file axiom_soap_over_http_sender.h
+ * @file axis2_soap_over_http_sender.h
  * @brief axis2 SOAP over HTTP sender
  */
 
@@ -42,17 +42,17 @@
 #endif
 
     /** Type name for struct axis2_soap_over_http_sender_ops */
-    typedef struct axiom_soap_over_http_sender_ops
-                axiom_soap_over_http_sender_ops_t;
+    typedef struct axis2_soap_over_http_sender_ops
+                axis2_soap_over_http_sender_ops_t;
     /** Type name for struct axis2_soap_over_http_sender_ */
-    typedef struct axiom_soap_over_http_sender axiom_soap_over_http_sender_t;
+    typedef struct axis2_soap_over_http_sender axis2_soap_over_http_sender_t;
 
 
     /**
      * SOAP over HTTP sender ops struct
      * Encapsulator struct for ops of axiom_soap_over_http_sender
      */
-    struct axiom_soap_over_http_sender_ops
+    struct axis2_soap_over_http_sender_ops
     {
         /**
          * @param sender sender
@@ -65,7 +65,7 @@
          */
         axis2_status_t (AXIS2_CALL *
                 send)(
-                    axiom_soap_over_http_sender_t *sender,
+                    axis2_soap_over_http_sender_t *sender,
                     const axis2_env_t *env, 
                     axis2_msg_ctx_t *msg_ctx,
                     axiom_soap_envelope_t *out,
@@ -80,7 +80,7 @@
          */
         axis2_status_t (AXIS2_CALL *
                 set_chunked)(
-                    axiom_soap_over_http_sender_t *sender,
+                    axis2_soap_over_http_sender_t *sender,
                     const axis2_env_t *env, 
                     axis2_bool_t chunked);
 
@@ -92,7 +92,7 @@
          */
         axis2_status_t (AXIS2_CALL *
                 set_om_output)(
-                    axiom_soap_over_http_sender_t *sender,
+                    axis2_soap_over_http_sender_t *sender,
                     const axis2_env_t *env, 
                     axiom_output_t *om_output);
 
@@ -104,7 +104,7 @@
          */
         axis2_status_t (AXIS2_CALL *
                 set_http_version)(
-                    axiom_soap_over_http_sender_t *sender,
+                    axis2_soap_over_http_sender_t *sender,
                     const axis2_env_t *env, 
                     axis2_char_t *version);
 
@@ -115,7 +115,7 @@
          */
         axis2_status_t (AXIS2_CALL *
                 free)(
-                    axiom_soap_over_http_sender_t *sender,
+                    axis2_soap_over_http_sender_t *sender,
                     const axis2_env_t *env);
     };
 
@@ -127,8 +127,8 @@
      * @param response pointer to response
      */
     axis2_status_t AXIS2_CALL
-    axiom_soap_over_http_sender_get_header_info(
-        axiom_soap_over_http_sender_t *sender,
+    axis2_soap_over_http_sender_get_header_info(
+        axis2_soap_over_http_sender_t *sender,
         const axis2_env_t *env, 
         axis2_msg_ctx_t *msg_ctx,
         axis2_http_simple_response_t *response);
@@ -140,8 +140,8 @@
      * @param response pointer to response
      */
     axis2_status_t AXIS2_CALL
-    axiom_soap_over_http_sender_process_response(
-        axiom_soap_over_http_sender_t *sender,
+    axis2_soap_over_http_sender_process_response(
+        axis2_soap_over_http_sender_t *sender,
         const axis2_env_t *env, 
         axis2_msg_ctx_t *msg_ctx,
         axis2_http_simple_response_t *response);
@@ -153,44 +153,44 @@
      * @param msg_ctx pointer to message context
      */
     axis2_status_t AXIS2_CALL
-    axiom_soap_over_http_sender_get_timeout_values(
-        axiom_soap_over_http_sender_t *sender,
+    axis2_soap_over_http_sender_get_timeout_values(
+        axis2_soap_over_http_sender_t *sender,
         const axis2_env_t *env, 
         axis2_msg_ctx_t *msg_ctx);
 
     /**
      * Axis2 SOAP over HTTP sender
      */
-    struct axiom_soap_over_http_sender
+    struct axis2_soap_over_http_sender
     {
         /** Operations of Axis2 SOAP over HTTP sender */
-        axiom_soap_over_http_sender_ops_t *ops;
+        axis2_soap_over_http_sender_ops_t *ops;
     };
 
 
     /**
      * @param env pointer to environment struct
      */
-    AXIS2_EXTERN axiom_soap_over_http_sender_t *AXIS2_CALL
-    axiom_soap_over_http_sender_create(
+    AXIS2_EXTERN axis2_soap_over_http_sender_t *AXIS2_CALL
+    axis2_soap_over_http_sender_create(
         const axis2_env_t *env);
 
 /********************* Start of function macros   ***************************/
 
 /** Send.
     @sa axis2_soap_over_http_sender_ops#send */
-#define AXIOM_SOAP_OVER_HTTP_SENDER_SEND(sender, env, msg_ctx, output, url, \
+#define AXIS2_SOAP_OVER_HTTP_SENDER_SEND(sender, env, msg_ctx, output, url, \
                   soap_action) ((sender)->ops->send (sender, env, msg_ctx\
                   ,output, url, soap_action))
 
 /** Set chunked.
     @sa axis2_soap_over_http_sender_ops#set_chunked */
-#define AXIOM_SOAP_OVER_HTTP_SENDER_SET_CHUNKED(sender, env, chunked) \
+#define AXIS2_SOAP_OVER_HTTP_SENDER_SET_CHUNKED(sender, env, chunked) \
                         ((sender)->ops->set_chunked(sender, env, chunked))
 
 /** Set om output.
     @sa axis2_soap_over_http_sender_ops#set_om_output */
-#define AXIOM_SOAP_OVER_HTTP_SENDER_SET_OM_OUTPUT(sender, env, om_output) \
+#define AXIS2_SOAP_OVER_HTTP_SENDER_SET_OM_OUTPUT(sender, env, om_output) \
                         ((sender)->ops->set_om_output (sender, env, om_output))
 
 /** Set http version.
@@ -200,7 +200,7 @@
 
 /** Frees the soap over http sender.
     @sa axis2_soap_over_http_sender_ops#free */
-#define AXIOM_SOAP_OVER_HTTP_SENDER_FREE(sender, env) \
+#define AXIS2_SOAP_OVER_HTTP_SENDER_FREE(sender, env) \
                         ((sender)->ops->free(sender, env))
 
 /************************* End of function macros *****************************/
@@ -209,4 +209,4 @@
 #ifdef __cplusplus
 }
 #endif
-#endif /* AXIOM_SOAP_OVER_HTTP_SENDER_H */
+#endif /* AXIS2_SOAP_OVER_HTTP_SENDER_H */
@@ -42,17 +42,17 @@
     /**
      * SOAP over HTTP sender ops struct
-     * Encapsulator struct for ops of axiom_soap_over_http_sender
+     * Encapsulator struct for ops of axis2_soap_over_http_sender
      */

Modified: webservices/axis2/trunk/c/modules/core/description/svc.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/description/svc.c?view=diff&rev=451883&r1=451882&r2=451883
==============================================================================